#!/usr/bin/sh
#copyright      "%c%"
#ident  "@(#)opensrc:src/perl/perl.sh /main/uw714mp/11"

#
# - dist/		perl_5.8.8 from http://www.perl.org/
# - patches/		the patches to be applied
# - perl.sh		build script -- this file
#

set -x
set -e

# Apply patches.
# This is not currently needed, but may be in the future

cd dist
CURDIR=`pwd`

## Use pure xenv.
cat >> ./hints/svr5.sh <<!
locincpth=""
loclibpth=""
!
# DESTDIR should not be set for this build.
unset DESTDIR
export DESTDIR

chmod u+x ./Configure

#
# First, create a version for the cross envorinment
#
if [ -f Makefile ]; then
  echo "## Cleaning out old perl build"
  $MAKE distclean > /dev/null 2>&1
fi
rm -f config.sh Policy.sh
echo "## Configuring perl for the cross environment"

echo "Configuring perl...Any error messages will be written"
echo "to $ROOT/src/work/perl.xenv.conf.out"

echo "## Configuring perl for the cross environment" > $ROOT/src/work/perl.xenv.conf.out 2>&1 
LD_LIBRARY_PATH="$TOOLS/usr/lib"
export LD_LIBRARY_PATH
./Configure \
	-des \
	-D cc="$CC" \
	-D cpp=i386cpp \
	-D ccflags="$CFLAGS" \
	-D cppflags="$CFLAGS" \
	-D libc="$TOOLS/usr/lib/libc.so.1" \
	-D ar=$AR \
	-D ld=$CC \
	-D myhostname=localhost \
	-D perladmin=root@localhost \
	-D cf_by='sco' \
	-D installprefix=$TOOLS/opt \
	-D installusrbinperl \
	-D prefix=$TOOLS/opt \
	-D archname=i386-unixware-thread-multi \
	-D glibpth="$TOOLS/usr/lib" \
	-D osname='unixware' \
	-D osvers='7.1.4' \
	-D usemymalloc=n \
	-D usethreads \
	-D useithreads \
	-D uselargefiles \
	-D pager='/usr/bin/pg' \
	-D sh=/u95/bin/sh \
	-D sh_path=/u95/bin/sh \
	-D libs='-lsocket -lnsl -ldl -lld -lm -lcrypt -ldb -lutil' \
	-A define:nm=i386nm  > $ROOT/src/work/perl.xenv.conf.out 2>&1
#	-D mksymlinks


# Fix the makefiles so the SONAME gets defined in libperl.so.XXX
for file in Makefile makefile
do
	cat $file | eval sed \'s/\$\(LD\) -o \$\@/\$\(LD\) -o \$\@ -Wl,-h\$\(LIBPERL\)/g\' > $file.new
	mv $file.new $file
done

# Make and install in $ROOT/$MACH/localbin.
echo "## Building perl for the cross environment"
$MAKE > $ROOT/src/work/perl.xenv.make.out 2>&1
echo "## Installing perl into the cross environment"
$MAKE install.perl > $ROOT/src/work/perl.xenv.make.install.out 2>&1
echo "## Creating a symbolic link for libperl.so"
LPDN="`grep 'shrpdir = ' Makefile | sed 's/.* = //g'`"
LPVER="`grep 'LIBPERL = ' Makefile | sed 's/.* = //g'`"
rm -f $LPDN/libperl.so
ln -s $LPVER $LPDN/libperl.so

# Now, create a version for the packaging $ROOT/$MACH tree (installs in /opt)
echo "## Clobbering old perl build"
if [ -f Makefile ]; then
  echo "## Cleaning out old perl build"
  $MAKE distclean > /dev/null 2>&1
fi
rm -f config.sh Policy.sh
echo "## Configuring perl for packaging"
echo "## Configuring perl for packaging" >> $ROOT/src/work/perl.conf.out 2>&1
./Configure \
	-des \
	-D cc="$CC" \
	-D cpp=i386cpp \
	-D ccflags="$CFLAGS" \
	-D cppflags="$CFLAGS" \
	-D libc="$TOOLS/usr/lib/libc.so.1" \
	-D ar=$AR \
	-D ld=$CC \
	-D myhostname=localhost \
	-D perladmin=root@localhost \
	-D cf_by='sco' \
	-D installprefix=$ROOT/$MACH/opt \
	-D installusrbinperl \
	-D prefix=/opt \
	-D archname=i386-unixware-thread-multi \
	-D glibpth="$TOOLS/usr/lib" \
	-D osname='unixware' \
	-D osvers='7.1.4' \
	-D usemymalloc=n \
	-D usethreads \
	-D useithreads \
	-D uselargefiles \
	-D pager='/usr/bin/pg' \
	-D sh=/u95/bin/sh \
	-D sh_path=/u95/bin/sh \
	-D libs='-lsocket -lnsl -ldl -lld -lm -lcrypt -lutil' \
	-A define:nm=i386nm  > $ROOT/src/work/perl.conf.out 2>&1
#	-D mksymlinks 
# Fix the makefiles so the SONAME gets defined in libperl.so.XXX
for file in Makefile makefile
do
	cat $file | eval sed \'s/\$\(LD\) -o \$\@/\$\(LD\) -o \$\@ -Wl,-h\$\(LIBPERL\)/g\' > $file.new
	mv $file.new $file
done

# Make and install in $ROOT/$MACH/opt.
echo "## Building perl for packaging"
$MAKE > $ROOT/src/work/perl.make.i386at.out 2>&1
echo "## Installing perl into $ROOT/$MACH"
$MAKE install > $ROOT/src/work/perl.make.install.i386at.out 2>&1

# And modify certain files so they are appropriate for an installed machine
echo "## Editing various perl files in $ROOT/$MACH"
while read file
do
  cat $ROOT/$MACH/$file | sed \
      -e "s%${TOOLS}%%g" \
      -e "s%${ROOT}/${MACH}/opt%/opt%g" \
      -e "s%i386ar%ar%g" \
      -e "s%i386cc%cc%g" \
      -e "s%i386cpp%cpp%g" \
      -e "s%i386nm%nm%g" \
      > $ROOT/$MACH/$file.NEW
  rm -rf $file
  mv $ROOT/$MACH/$file.NEW $ROOT/$MACH/$file
done <<-!EOF
  opt/lib/perl5/5.8.8/i386-unixware-thread-multi/Config.pm
  opt/lib/perl5/5.8.8/i386-unixware-thread-multi/Config_heavy.pl
  opt/lib/perl5/5.8.8/i386-unixware-thread-multi/.packlist
!EOF

# Install copyright files.
$INSTALL -d $ROOT/$MACH/usr/share/perl
$INSTALL -m 0444 ./Copying $ROOT/$MACH/usr/share/perl

exit 0
